@@ -26,7 +26,9 @@ def create_cohort() -> Cohort:
     Add datasets in the cohort. There exists only one cohort for the workflow run.
     """
     analysis_dataset_name = get_config()['workflow']['dataset']
-    dataset_names = get_config()['workflow'].get('datasets', [analysis_dataset_name])
+    dataset_names = get_config()['workflow'].get(
+        'input_datasets', [analysis_dataset_name]
+    )
     skip_datasets = get_config()['workflow'].get('skip_datasets', [])
     dataset_names = [d for d in dataset_names if d not in skip_datasets]
 
@@ -151,8 +153,10 @@ def _populate_analysis(cohort: Cohort) -> None:
                     analysis.output,
                     sample.make_gvcf_path().path,
                 )
+                sample.gvcf = sample.make_gvcf_path()
             if (analysis := cram_by_sid.get(sample.id)) and analysis.output:
                 assert analysis.output == sample.make_cram_path().path, analysis.output
+                sample.cram = sample.make_cram_path()
 
 
 def _populate_participants(cohort: Cohort) -> None:
