@@ -1020,7 +1020,7 @@ class SampleStage(Stage[Sample], ABC):
                 f'{len(cohort.get_datasets())}/'
                 f'{len(cohort.get_datasets(only_active=False))} '
                 f'usable (active=True) datasets found in the cohort. Check that '
-                f'`workflow.datasets` is provided, and not all datasets are skipped '
+                f'`workflow.input_datasets` is provided, and not all datasets are skipped '
                 f'via workflow.skip_datasets`'
             )
             return output_by_target
@@ -1114,7 +1114,7 @@ class DatasetStage(Stage, ABC):
                 f'{len(cohort.get_datasets())}/'
                 f'{len(cohort.get_datasets(only_active=False))} '
                 f'usable (active=True) datasets found in the cohort. Check that '
-                f'`workflow.datasets` is provided, and not all datasets are skipped '
+                f'`workflow.input_datasets` is provided, and not all datasets are skipped '
                 f'via workflow.skip_datasets`'
             )
             return output_by_target
